@@ -15,4 +15,7 @@ MARKDOWN_SET_NAME = getattr(
 
 MARKDOWN_PREVIEW_TEMPLATE = getattr(settings, 'MARKDOWN_PREVIEW_TEMPLATE', 'django_markdown/preview.html')
 MARKDOWN_STYLE = getattr(settings, 'MARKDOWN_STYLE', 'django_markdown/preview.css')
+MARKDOWN_PROTECT_PREVIEW = getattr(settings, 'MARKDOWN_PROTECT_PREVIEW', False)
+
 STATIC_URL = settings.STATIC_URL or settings.MEDIA_URL
+LOGIN_URL = settings.LOGIN_URL
